# LoggingLogentriesAdditional


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**port** | **int** | The port number. | [optional]  if omitted the server will use the default value of 20000
**token** | **str** | Use token based authentication. | [optional] 
**use_tls** | [**LoggingUseTls**](LoggingUseTls.md) |  | [optional] 
**region** | **str** | The region to which to stream logs. | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


